==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ChartGroupDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescriptionMetadata } from "./ChartSortDescriptionDescriptionMetadata";
import { ChartGroupDescriptionDescription } from "./ChartGroupDescriptionDescription";
/**
 * @hidden
 */
var ChartGroupDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartGroupDescriptionDescriptionMetadata, _super);
    function ChartGroupDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartGroupDescriptionDescriptionMetadata.b = function (a) {
        if (ChartGroupDescriptionDescriptionMetadata.a == null) {
            ChartGroupDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartGroupDescriptionDescriptionMetadata.c(ChartGroupDescriptionDescriptionMetadata.a);
        }
        if (a.g(ChartGroupDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.s(ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.c = function (a) {
        ChartSortDescriptionDescriptionMetadata.c(a);
    };
    ChartGroupDescriptionDescriptionMetadata.d = function (a) {
        ChartGroupDescriptionDescriptionMetadata.b(a);
        a.u("ChartGroupDescription", function () { return new ChartGroupDescriptionDescription(); });
        a.t("ChartGroupDescription", ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.$t = markType(ChartGroupDescriptionDescriptionMetadata, 'ChartGroupDescriptionDescriptionMetadata');
    ChartGroupDescriptionDescriptionMetadata.a = null;
    return ChartGroupDescriptionDescriptionMetadata;
}(Base));
export { ChartGroupDescriptionDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ChartGroupDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ChartSortDescriptionDescriptionMetadata } from "./ChartSortDescriptionDescriptionMetadata";
import { ChartGroupDescriptionDescription } from "./ChartGroupDescriptionDescription";
/**
 * @hidden
 */
var ChartGroupDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ChartGroupDescriptionDescriptionMetadata, _super);
    function ChartGroupDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChartGroupDescriptionDescriptionMetadata.b = function (a) {
        if (ChartGroupDescriptionDescriptionMetadata.a == null) {
            ChartGroupDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChartGroupDescriptionDescriptionMetadata.c(ChartGroupDescriptionDescriptionMetadata.a);
        }
        if (a.j(ChartGroupDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.y(ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.c = function (a) {
        ChartSortDescriptionDescriptionMetadata.c(a);
    };
    ChartGroupDescriptionDescriptionMetadata.d = function (a) {
        ChartGroupDescriptionDescriptionMetadata.b(a);
        a.aa("ChartGroupDescription", function () { return new ChartGroupDescriptionDescription(); });
        a.z("ChartGroupDescription", ChartGroupDescriptionDescriptionMetadata.a);
    };
    ChartGroupDescriptionDescriptionMetadata.$t = markType(ChartGroupDescriptionDescriptionMetadata, 'ChartGroupDescriptionDescriptionMetadata');
    ChartGroupDescriptionDescriptionMetadata.a = null;
    return ChartGroupDescriptionDescriptionMetadata;
}(Base));
export { ChartGroupDescriptionDescriptionMetadata };
